@@ -16,21 +16,24 @@ Provides the classes :class:`DigiflowImage` and :class:`DigiflowMovie`.
 
 from __future__ import division, print_function
 
+from builtins import range
+from builtins import object
 import numpy as np
+import matplotlib.pyplot as plt
 
 from fluiddyn.io.binary import BinFile
 from fluiddyn.util import Params
 
 ddatatypes = {
     0x1001: '8 bit image',
-    0x11001:'8 bit multi-plane image',
-    0x12001:'Compressed 8 bit image',
+    0x11001: '8 bit multi-plane image',
+    0x12001: 'Compressed 8 bit image',
     0x1004: '32 bit image',
-    0x11004:'32 bit multi-plane image',
-    0x12004:'Compressed 32 bit image',
+    0x11004: '32 bit multi-plane image',
+    0x12004: 'Compressed 32 bit image',
     0x1008: '64 bit image',
-    0x11008:'64 bit multi-plane image',
-    0x12008:'Compressed 64 bit image',
+    0x11008: '64 bit multi-plane image',
+    0x12008: 'Compressed 64 bit image',
     0x1014: '32 bit range',
     0x1018: '64 bit range',
     0x1100: 'Rescale image',
@@ -44,8 +47,7 @@ ddatatypes = {
     0x3003: 'Creator details',
     0x3018: 'Image time',
     0x4008: 'Image coordinates',
-    0x4108: 'Image plane details'
-}
+    0x4108: 'Image plane details'}
 
 keys_image = [
     '8 bit image',
@@ -56,8 +58,7 @@ keys_image = [
     'Compressed 32 bit image',
     '64 bit image',
     '64 bit multi-plane image',
-    'Compressed 64 bit image'
-    ]
+    'Compressed 64 bit image']
 
 
 class DigiflowImage(object):
@@ -65,16 +66,16 @@ class DigiflowImage(object):
 
 
     """
-    def __init__(self, file_path=None):
+    def __init__(self, path_file=None):
 
-        if file_path is not None:
-            self.file_path = file_path
+        if path_file is not None:
+            self.path_file = path_file
             self._load()
 
     def _load(self):
         """Loads the file."""
 
-        with BinFile(self.file_path) as f:
+        with BinFile(self.path_file) as f:
             # header of the file:
             id_format = f.readt(32, 's')
             version = f.readt(1, 'I')
@@ -184,7 +185,7 @@ class DigiflowImage(object):
             infop.keys = []
             infop.params = []
             infop.dunno = []
-            for ip in xrange(nplanes):
+            for ip in range(nplanes):
                 infop.codes.append(int(
                     '{0:x}'.format(f.readt(1, 'uint32'))))
                 infop.keys.append(f.readt(32, 's'))
@@ -264,15 +265,17 @@ class DigiflowMovie(object):
     """A digiflow movie (.dfm, "movies", set of images).
 
     """
-    def __init__(self, file_path=None):
-        if file_path is not None:
-            self.file_path = file_path
+    def __init__(self, path_file=None):
+        if path_file is not None:
+            self.path_file = path_file
             self._load_info()
 
+            self.deltat = self.movie_header['dtSampleSpacing']
+
     def _load_info(self):
         """Loads the file."""
 
-        with BinFile(self.file_path) as f:
+        with BinFile(self.path_file) as f:
             # do not change the order of these lines!
             # do not comment one of these lines!
             self._read_file_header(f)
@@ -285,7 +288,7 @@ class DigiflowMovie(object):
             self.iFrameNumber = temp[:, 0]
             self.iPtrFrame = temp[:, 1]
 
-            self.nb_imags = len(self.iFrameNumber)
+            self.nb_frames = len(self.iFrameNumber)
 
     def _read_file_header(self, f):
         # header of the file:
@@ -349,111 +352,122 @@ class DigiflowMovie(object):
         self.movie_header = d
 
     def __getitem__(self, arg):
-        # print(arg)
 
-        # return arg
+        # itstart = 0
+        # itstop = self.nb_frames-1
+        # itstep = 1
 
-        itstart = 0
-        itstop = self.nb_imags-1
-        itstep = 1
+        # iystart = 0
+        # iystop = self.shape_im[0]
+        # iystep = 1
 
-        iystart = 0
-        iystop = self.shape_im[0]
-        iystep = 1
-
-        ixstart = 0
-        ixstop = self.shape_im[1]
-        ixstep = 1
+        # ixstart = 0
+        # ixstop = self.shape_im[1]
+        # ixstep = 1
 
         if isinstance(arg, int):
-            itstart = 0
-            itstop = arg+1
-            itstep = 1
+            with open(self.path_file) as f:
+                f.seek(self.iPtrFrame[arg])
+                return np.fromfile(
+                    f, dtype=np.uint8,
+                    count=self.size_im).reshape(self.shape_im)
 
         elif isinstance(arg, slice):
-            itstart = arg.start
-            itstop = arg.stop
-            itstep = arg.step
+            raise NotImplementedError
+            # itstart = arg.start
+            # itstop = arg.stop
+            # itstep = arg.step
 
         elif isinstance(arg, tuple):
-            itstart = arg[0].start
-            itstop = arg[0].stop
-            itstep = arg[0].step
+            raise NotImplementedError
+            # itstart = arg[0].start
+            # itstop = arg[0].stop
+            # itstep = arg[0].step
 
-        nb_values_between_frames = self.iPtrFrame[1] - self.iPtrFrame[0]
+        # nb_values_between_frames = self.iPtrFrame[1] - self.iPtrFrame[0]
 
-        shape_ret = [nb_frames]+list(self.shape_im)
-        size_im = self.size_im
-        nb_values_to_jump_startim = 0
-        nb_values_to_jump_endim = nb_values_between_frames - size_im
+        # shape_ret = [nb_frames] + list(self.shape_im)
+        # size_im = self.size_im
+        # nb_values_to_jump_startim = 0
+        # nb_values_to_jump_endim = nb_values_between_frames - size_im
 
-        ret = np.empty(shape_ret)
+        # ret = np.empty(shape_ret)
 
-        with BinFile(self.file_path) as f:
-            f.seek(self.iPtrFrame[iframe_start])
-            for iframe in xrange(nb_frames):
-                # temp = np.array(f.readt(self.size_im, 'uint8'))
-                # ret[iframe].flat = temp#.reshape(self.shape_im)
-                f.seek(nb_values_to_jump_startim, 1)
-                ret[iframe].flat = f.readt(size_im, 'uint8')
-                f.seek(nb_values_to_jump_endim, 1)
+        # with BinFile(self.path_file) as f:
+        #     f.seek(self.iPtrFrame[iframe_start])
+        #     for iframe in xrange(nb_frames):
+        #         # temp = np.array(f.readt(self.size_im, 'uint8'))
+        #         # ret[iframe].flat = temp#.reshape(self.shape_im)
+        #         f.seek(nb_values_to_jump_startim, 1)
+        #         ret[iframe].flat = f.readt(size_im, 'uint8')
+        #         f.seek(nb_values_to_jump_endim, 1)
 
-        if nb_frames == 1:
-            return ret[0]
-        else:
-            return ret
+        # if nb_frames == 1:
+        #     return ret[0]
+        # else:
+        #     return ret
 
-    def load_contiguous_frames2(self, iframe_start, nb_frames=1):
+    # def load_contiguous_frames2(self, iframe_start, nb_frames=1):
 
-        if iframe_start+1 > self.nb_imags:
-            raise ValueError('A non excisting frame has been asked.')
+    #     if iframe_start+1 > self.nb_frames:
+    #         raise ValueError('A non excisting frame has been asked.')
 
-        if iframe_start+nb_frames > self.nb_imags:
-            print('too many frames asked...')
-            nb_frames = self.nb_imags - iframe_start
+    #     if iframe_start+nb_frames > self.nb_frames:
+    #         print('too many frames asked...')
+    #         nb_frames = self.nb_frames - iframe_start
 
-        nb_values_between_frames = self.iPtrFrame[1] - self.iPtrFrame[0]
+    #     ret = np.empty([nb_frames]+list(self.shape_im))
 
-        nb_values_to_jump = (
-            self.iPtrFrame[1] - self.iPtrFrame[0] - self.size_im)
+    #     if self.nb_frames > 1:
+    #         nb_values_between_frames = self.iPtrFrame[1] - self.iPtrFrame[0]
+    #     else:
+    #         nb_values_between_frames = self.size_im
 
-        ret = np.empty([nb_frames]+list(self.shape_im))
+    #     with BinFile(self.path_file) as f:
+    #         f.seek(self.iPtrFrame[iframe_start])
+    #         temp = f.readt(nb_frames*nb_values_between_frames, 'uint8')
 
-        with BinFile(self.file_path) as f:
-            f.seek(self.iPtrFrame[iframe_start])
-            temp = f.readt(nb_frames*nb_values_between_frames, 'uint8')
+    #     for iframe in xrange(nb_frames):
+    #         istart = iframe*nb_values_between_frames
+    #         temp2 = np.array(temp[istart:istart+self.size_im])
+    #         ret[iframe] = temp2.reshape(self.shape_im)
 
-        for iframe in xrange(nb_frames):
-            istart = iframe*nb_values_between_frames
-            temp2 = np.array(temp[istart:istart+self.size_im])
-            ret[iframe] = temp2.reshape(self.shape_im)
-
-        if nb_frames == 1:
-            return ret[0]
-        else:
-            return ret
+    #     if nb_frames == 1:
+    #         return ret[0]
+    #     else:
+    #         return ret
 
     def load_contiguous_frames(self, iframe_start, nb_frames=1):
 
-        if iframe_start+1 > self.nb_imags:
+        if iframe_start+1 > self.nb_frames:
             raise ValueError('A non-existing frame has been asked.')
 
-        if iframe_start+nb_frames > self.nb_imags:
+        if iframe_start+nb_frames > self.nb_frames:
             print('too many frames asked...')
-            nb_frames = self.nb_imags - iframe_start
+            nb_frames = self.nb_frames - iframe_start
 
-        nb_values_to_jump = (
-            self.iPtrFrame[1] - self.iPtrFrame[0] - self.size_im)
+        ret = np.empty([nb_frames] + list(self.shape_im))
 
-        ret = np.empty([nb_frames]+list(self.shape_im))
+        if self.nb_frames > 1:
+            nb_values_to_jump = (
+                self.iPtrFrame[1] - self.iPtrFrame[0] - self.size_im)
+        else:
+            nb_values_to_jump = 0
 
-        with BinFile(self.file_path) as f:
+        # with BinFile(self.path_file) as f:
+        #     f.seek(self.iPtrFrame[iframe_start])
+        #     for iframe in xrange(nb_frames):
+        #         # ret[iframe].flat = f.readt(self.size_im, 'uint8')
+        #         ret[iframe].flat = np.fromfile(
+        #             f, dtype=np.uint8, count=self.size_im)
+        #         f.seek(nb_values_to_jump, 1)
+
+        with open(self.path_file, 'rb') as f:
             f.seek(self.iPtrFrame[iframe_start])
-            for iframe in xrange(nb_frames):
-                # temp = np.array(f.readt(self.size_im, 'uint8'))
-                # ret[iframe].flat = temp#.reshape(self.shape_im)
-
-                ret[iframe].flat = f.readt(self.size_im, 'uint8')
+            for iframe in range(nb_frames):
+                # ret[iframe].flat = f.readt(self.size_im, 'uint8')
+                ret[iframe].flat = np.fromfile(
+                    f, dtype=np.uint8, count=self.size_im)
                 f.seek(nb_values_to_jump, 1)
 
         if nb_frames == 1:
@@ -463,59 +477,127 @@ class DigiflowMovie(object):
 
     def _test_end_of_file(self, i):
         "Seems to reach eof if i > 275 but why ?"
-        with BinFile(self.file_path) as f:
+        with BinFile(self.path_file) as f:
             f.seek(self.iPtrFrame[-1])
             im = f.readt(self.size_im, 'uint8')
 
             print('last values in last image:\n', im[-10:])
             print('after the last values:\n', f.readt(i, 'uint8'))
 
-    # def save(self):
-    #     pass
+    def show_movie(self, i_start, i_stop, i_step=1, fps=4, decimate=4):
+        plt.ion()
+        fig = plt.figure()
+        ax = plt.gca()
 
+        data = self[i_start]
+        if decimate > 1:
+            data = data[::decimate, ::decimate]
 
-def plot_im(im):
-    import fluiddyn.figs as figs
+        quadmesh = ax.pcolormesh(data)
+        quadmesh.set_clim([0., 255.])
 
-    import matplotlib.pyplot as plt
+        ax.set_xlim([0, data.shape[1]])
+        ax.set_ylim([0, data.shape[0]])
 
-    figures = figs.Figures(
-        hastosave=False, for_beamer=False, fontsize=20)
-    size_axe = [0.15, 0.12, 0.8, 0.76]
+        for i in range(i_start+i_step, i_stop, i_step):
+            with open(self.path_file) as f:
+                f.seek(self.iPtrFrame[i])
+                data = np.fromfile(
+                    f, dtype=np.uint8,
+                    count=self.size_im).reshape(self.shape_im)
 
-    fig = figures.new_figure(
-        name_file='fig_im',
-        fig_width_mm=170, fig_height_mm=220,
-        size_axe=size_axe
-        )
+                if decimate > 1:
+                    data = data[::decimate, ::decimate]
 
-    ax1 = fig.gca()
+            quadmesh.set_array(data.ravel())
+            fig.canvas.draw()
 
-    ax1.set_xlabel(r'$x$ (pixels)')
-    ax1.set_ylabel(r'$z$ (pixels)')
+    def plot_image(self, i_image, decimate=1, clim=None, cmap=None):
+        plt.ion()
+        plt.figure()
+        ax = plt.gca()
 
-    pc = ax1.pcolormesh(im, cmap=plt.cm.hsv, shading='flat')
+        data = self[i_image]
+        if decimate > 1:
+            data = data[::decimate, ::decimate]
 
-    fig.colorbar(pc)
+        # if cmap is None:
+        #     cmap = plt.cm.hsv
 
-    ax1.set_xlim([0, im.shape[1]])
-    ax1.set_ylim([0, im.shape[0]])
+        quadmesh = ax.pcolormesh(data, cmap=cmap, shading='flat')
 
-    figs.show()
+        if clim is not None:
+            quadmesh.set_clim(clim)
+
+        ax.set_xlim([0, data.shape[1]])
+        ax.set_ylim([0, data.shape[0]])
+
+        plt.show()
+
+    def make_time_serie(self, i_start, i_stop, i_x, i_step=1,
+                        has_to_plot=True, cmap=None):
+
+        if i_stop > self.nb_frames - 1:
+            i_stop = self.nb_frames - 1
+
+        inds_t = list(range(i_start, i_stop+1, i_step))
+
+        time_serie = np.zeros([self.shape_im[0], len(inds_t)])
+
+        for it in inds_t:
+            a = self[it]
+            time_serie[:, it] = a[:, i_x]
+
+        if has_to_plot:
+            plt.ion()
+            plt.figure()
+            ax = plt.gca()
+            ax.pcolormesh(time_serie, cmap=cmap, shading='flat')
+            plt.show()
+
+        return time_serie
 
 
 if __name__ == '__main__':
 
-    file_path = (
+    def plot_im(im):
+        import fluiddyn.figs as figs
+
+        import matplotlib.pyplot as plt
+
+        figures = figs.Figures(
+            hastosave=False, for_beamer=False, fontsize=20)
+        size_axe = [0.15, 0.12, 0.8, 0.76]
+
+        fig = figures.new_figure(
+            name_file='fig_im',
+            fig_width_mm=170, fig_height_mm=220,
+            size_axe=size_axe)
+
+        ax1 = fig.gca()
+
+        ax1.set_xlabel(r'$x$ (pixels)')
+        ax1.set_ylabel(r'$z$ (pixels)')
+
+        pc = ax1.pcolormesh(im, cmap=plt.cm.hsv, shading='flat')
+
+        fig.colorbar(pc)
+
+        ax1.set_xlim([0, im.shape[1]])
+        ax1.set_ylim([0, im.shape[0]])
+
+        figs.show()
+
+    path_file = (
         '/home/pa371/Data_reasons_pa371/Dropbox'
         '/Strat_inclined_duct/Decomposition/Data_exp/Exp_m7'
         '/clean_m7_lif3_0036.dfi'
         )
 
-    print(file_path)
-    dfi = DigiflowImage(file_path)
+    print(path_file)
+    dfi = DigiflowImage(path_file)
 
     plot_im(dfi.data[0])
 
-    # dfm = DigiflowMovie(file_path)
+    # dfm = DigiflowMovie(path_file)
     # im = dfm.load_contiguous_frames(10, nb_frames=3)
